/* ======================
 * Eastwood Chart Servlet
 * ======================
 *
 * (C) Copyright 2007, by Object Refinery Limited.
 *
 * Project Info:  http://www.jfree.org/eastwood/index.html
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
 * in the United States and other countries.]
 *
 * ------------
 * GXYPlot.java
 * ------------
 * (C) Copyright 2007, by Object Refinery Limited.
 *
 * Original Author:  David Gilbert (for Object Refinery Limited);
 *
 * Changes
 * -------
 * 13-Dec-2007 : Version 1 (DG);
 *
 */

package org.jfree.eastwood;

import java.awt.GradientPaint;
import java.awt.Graphics2D;
import java.awt.Paint;
import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;

import org.jfree.chart.plot.XYPlot;

/**
 * A custom plot class (adds support for drawing background gradients). 
 */
class GXYPlot extends XYPlot {
    
    /** The angle in radians. */
    private double angle;
    
    /** The factor for the start of the background gradient. */
    private double f0;
    
    /** The factor for the end of the background gradient. */
    private double f1;
    
    /**
     * Default constructor.
     */
    public GXYPlot() {
        this.angle = 0.0;
        this.f0 = 0.0;
        this.f1 = 1.0;
    }
    
    /**
     * Sets the angle (in radians).
     * 
     * @param angle  the angle.
     */
    public void setAngle(double angle) {
        this.angle = angle; 
    }
    
    /**
     * Sets the factor for the beginning of the background gradient.
     * 
     * @param f0  the factor.
     */
    public void setF0(double f0) {
        this.f0 = f0;
    }
    
    /**
     * Sets the factor for the end of the background gradient.
     * 
     * @param f1  the factor.
     */
    public void setF1(double f1) {
        this.f1 = f1;
    }

    /**
     * Draws the background for the plot.
     *
     * @param g2  the graphics device.
     * @param area  the area.
     */
    public void drawBackground(Graphics2D g2, Rectangle2D area) {
        Paint p = getBackgroundPaint();
        if (p instanceof GradientPaint) {
            // do the transformation directly
            GradientPaint gp = (GradientPaint) p;
            double r = (this.f1 - this.f0) * area.getWidth();
            Point2D p0 = new Point2D.Double(area.getMinX() + this.f0 
                    * area.getWidth(), area.getMaxY());
            Point2D p1 = new Point2D.Double(p0.getX() + r 
                    * Math.cos(this.angle), p0.getY() - r 
                    * Math.sin(this.angle));
            p = new GradientPaint(p0, gp.getColor1(), p1, 
                    gp.getColor2());
        }            
        g2.setPaint(p);
        g2.fill(area);    
    }

}
