/* ======================
 * Eastwood Chart Servlet
 * ======================
 *
 * (C) Copyright 2007, by Object Refinery Limited.
 *
 * Project Info:  http://www.jfree.org/eastwood/index.html
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
 * in the United States and other countries.]
 *
 * ---------------
 * GValueAxis.java
 * ---------------
 * (C) Copyright 2007, by Object Refinery Limited.
 *
 * Original Author:  David Gilbert (for Object Refinery Limited);
 *
 * Changes
 * -------
 * 13-Dec-2007 : Version 1 (DG);
 *
 */

package org.jfree.eastwood;

import java.util.List;

import org.jfree.chart.labels.XYSeriesLabelGenerator;
import org.jfree.data.xy.XYDataset;

/**
 * A series label generator that ignores the series keys and just returns
 * the strings specified in the constructor.  This is used by the 
 * {@link ChartServlet} servlet to emulate the Google Chart API.
 */
public class GXYSeriesLabelGenerator implements XYSeriesLabelGenerator {

    /** Storage for the labels. */
    private List labels;
    
    /**
     * Creates a new label generator.
     * 
     * @param labels  a list of labels (<code>null</code> not permitted).
     */
    public GXYSeriesLabelGenerator(List labels) {
        if (labels == null) {
            throw new IllegalArgumentException("Null 'labels' argument.");
        }
        this.labels = labels;    
    }
    
    /**
     * Returns a string that will be used as the label for the specified 
     * series.
     * 
     * @param dataset  the dataset (ignored here).
     * @param series  the series index.
     * 
     * @return The label string.
     */
    public String generateLabel(XYDataset dataset, int series) {
        Object item = this.labels.get(series);
        if (item != null) {
            return item.toString();
        }
        else {
            return "";
        }
    }

}
